server_client_20141231_085104

### config1

Total tests | Passed | Failed | Skipped | Start time | End time | Execution time | Naarad
--- | --- | --- | --- | --- | --- | --- | ---
12 | 2 | 10 | 0 | 2014-12-31 08:51:10 | 2014-12-31 08:55:17 | 247.050562143 sec | Report

###

Test Name | Result | Description
--- | --- | ---
test_negative_correctness | Failed | Tests sending non-integers to the server ; Verify 0 is received since no valid integers were sent
test_client_isolation | Failed | Tests what happens when the client is faulty ; Verify that timeout messages are received
test_bouncing_with_state | Failed | Tests that bouncing the server retains state ; Verify that the sum 500,500 is received
test_multi_client_perf | Failed | Tests the performance of a server when handling multiple clients ; Validate server max qps is >1000 and mean latency is <1 sec
test_client_timeout | Failed | Tests what happens when the client does not finish a full request ; Verify that timeout messages are received
test_race_condition | Failed | Tests what happens when two clients send requests to the same server
test_fault_tolerance | Failed | Tests what happens when servers are stopped ; Verify that 10 is received
test_redlining | Failed | Sends a large sample of integers to the server. ; Verify max latency of server is <0.5 sec
test_single_client_perf | Failed | Tests the performance of a server when handling single client ; Validate server max qps is >100 and mean latency is <0.2 sec
test_ordered_events | Passed | Tests that integers to a server are received in the same order that they are sent ; Validates that the integers 1, 2, and 3, were sent in that specific order
test_correctness | Failed | Tests if the correct sums are calculated ; Verify the correct sums are received
test_load_balance | Passed | Tests if clients perform correct load balancing ; Verify that one server did not process all requests

###

Config Key | Value
--- | ---